timespantools.timespan_2_starts_after_timespan_1_stops
======================================================

.. autofunction:: abjad.tools.timespantools.timespan_2_starts_after_timespan_1_stops.timespan_2_starts_after_timespan_1_stops
